@@ -1,6 +1,7 @@
-
 from typing import Optional
+
 import numpy as np
+
 from paramak import ExtrudeCircleShape
 
 
@@ -31,11 +32,7 @@ class CoolantChannelRingStraight(ExtrudeCircleShape):
         **kwargs
     ) -> None:
 
-        super().__init__(
-            distance=height,
-            radius=channel_radius,
-            **kwargs
-        )
+        super().__init__(distance=height, radius=channel_radius, **kwargs)
 
         self.height = height
         self.channel_radius = channel_radius
@@ -61,7 +58,9 @@ class CoolantChannelRingStraight(ExtrudeCircleShape):
                 0 + self.start_angle,
                 360 + self.start_angle,
                 self.number_of_coolant_channels,
-                endpoint=False))
+                endpoint=False,
+            )
+        )
 
         self.azimuth_placement_angle = angles
 
