@@ -9,6 +9,13 @@ class RotateSplineShape(RotateMixedShape):
     Args:
         rotation_angle: The rotation_angle to use when revolving the solid.
             Defaults to 360.0.
+        color: the color to use when exporting the shape to CAD formats that
+            support color. A tuple of three floats each ranging between 0
+            and 1.
+        name: the name of the shape, used to name files when exporting and
+            as a legend in plots.
+        translate: distance to translate / move the shape by. Specified as
+            a vector of (X,Y,Z) directions.
     """
 
     def __init__(
@@ -23,10 +30,4 @@ class RotateSplineShape(RotateMixedShape):
         **kwargs
     ):
 
-        super().__init__(
-            rotation_angle=rotation_angle,
-            color=color,
-            connection_type="spline",
-            name=name,
-            **kwargs
-        )
+        super().__init__(rotation_angle=rotation_angle, color=color, connection_type="spline", name=name, **kwargs)
